==> kubernetes-model-core-5.0.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/CephFSVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CephFSVolumeSourceFluent<A extends CephFSVolumeSourceFluent<A>> extends Fluent<A> {


    public A addToMonitors(int index,String item);
    public A setToMonitors(int index,String item);
    public A addToMonitors(String... items);
    public A addAllToMonitors(Collection<String> items);
    public A removeFromMonitors(String... items);
    public A removeAllFromMonitors(Collection<String> items);
    public List<String> getMonitors();
    public String getMonitor(int index);
    public String getFirstMonitor();
    public String getLastMonitor();
    public String getMatchingMonitor(Predicate<String> predicate);
    public Boolean hasMatchingMonitor(Predicate<String> predicate);
    public A withMonitors(List<String> monitors);
    public A withMonitors(String... monitors);
    public Boolean hasMonitors();
    public A addNewMonitor(String arg1);
    public A addNewMonitor(StringBuilder arg1);
    public A addNewMonitor(StringBuffer arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public String getSecretFile();
    public A withSecretFile(String secretFile);
    public Boolean hasSecretFile();
    public A withNewSecretFile(String arg1);
    public A withNewSecretFile(StringBuilder arg1);
    public A withNewSecretFile(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public LocalObjectReference getSecretRef();
    public LocalObjectReference buildSecretRef();
    public A withSecretRef(LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public A withNewSecretRef(String name);
    public CephFSVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public CephFSVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item);
    public CephFSVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public CephFSVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public CephFSVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item);
    public String getUser();
    public A withUser(String user);
    public Boolean hasUser();
    public A withNewUser(String arg1);
    public A withNewUser(StringBuilder arg1);
    public A withNewUser(StringBuffer arg1);
    public interface SecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LocalObjectReferenceFluent<CephFSVolumeSourceFluent.SecretRefNested<N>> {

            public N and();
            public N endSecretRef();    }


}

==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/CephFSVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CephFSVolumeSourceFluent<A extends CephFSVolumeSourceFluent<A>> extends Fluent<A> {


    public A addToMonitors(int index,String item);
    public A setToMonitors(int index,String item);
    public A addToMonitors(String... items);
    public A addAllToMonitors(Collection<String> items);
    public A removeFromMonitors(String... items);
    public A removeAllFromMonitors(Collection<String> items);
    public List<String> getMonitors();
    public String getMonitor(int index);
    public String getFirstMonitor();
    public String getLastMonitor();
    public String getMatchingMonitor(Predicate<String> predicate);
    public Boolean hasMatchingMonitor(Predicate<String> predicate);
    public A withMonitors(List<String> monitors);
    public A withMonitors(String... monitors);
    public Boolean hasMonitors();
    public A addNewMonitor(StringBuilder arg1);
    public A addNewMonitor(int[] arg1,int arg2,int arg3);
    public A addNewMonitor(char[] arg1);
    public A addNewMonitor(StringBuffer arg1);
    public A addNewMonitor(byte[] arg1,int arg2);
    public A addNewMonitor(byte[] arg1);
    public A addNewMonitor(char[] arg1,int arg2,int arg3);
    public A addNewMonitor(byte[] arg1,int arg2,int arg3);
    public A addNewMonitor(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewMonitor(String arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(int[] arg1,int arg2,int arg3);
    public A withNewPath(char[] arg1);
    public A withNewPath(StringBuffer arg1);
    public A withNewPath(byte[] arg1,int arg2);
    public A withNewPath(byte[] arg1);
    public A withNewPath(char[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPath(String arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public String getSecretFile();
    public A withSecretFile(String secretFile);
    public Boolean hasSecretFile();
    public A withNewSecretFile(StringBuilder arg1);
    public A withNewSecretFile(int[] arg1,int arg2,int arg3);
    public A withNewSecretFile(char[] arg1);
    public A withNewSecretFile(StringBuffer arg1);
    public A withNewSecretFile(byte[] arg1,int arg2);
    public A withNewSecretFile(byte[] arg1);
    public A withNewSecretFile(char[] arg1,int arg2,int arg3);
    public A withNewSecretFile(byte[] arg1,int arg2,int arg3);
    public A withNewSecretFile(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSecretFile(String arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public LocalObjectReference getSecretRef();
    public LocalObjectReference buildSecretRef();
    public A withSecretRef(LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public A withNewSecretRef(String name);
    public CephFSVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public CephFSVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item);
    public CephFSVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public CephFSVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public CephFSVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item);
    public String getUser();
    public A withUser(String user);
    public Boolean hasUser();
    public A withNewUser(StringBuilder arg1);
    public A withNewUser(int[] arg1,int arg2,int arg3);
    public A withNewUser(char[] arg1);
    public A withNewUser(StringBuffer arg1);
    public A withNewUser(byte[] arg1,int arg2);
    public A withNewUser(byte[] arg1);
    public A withNewUser(char[] arg1,int arg2,int arg3);
    public A withNewUser(byte[] arg1,int arg2,int arg3);
    public A withNewUser(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUser(String arg1);
    public interface SecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LocalObjectReferenceFluent<CephFSVolumeSourceFluent.SecretRefNested<N>> {

            public N and();
            public N endSecretRef();    }


}
